VectorTileProvider class abstract

Implementers

Constructors

VectorTileProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximumZoom → int
no setter
minimumZoom → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TileProviderType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provide(TileIdentity tile) → Future<Uint8List>
provides a tile as a pbf or mvt format for type of TileProviderType.vector or png for TileProviderType.raster
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited